[Openmp-commits] [openmp] r238713 - Apply name change to tools/* files.

Jonathan Peyton jonathan.l.peyton at intel.com
Sun May 31 19:41:45 PDT 2015


Author: jlpeyton
Date: Sun May 31 21:41:44 2015
New Revision: 238713

URL: http://llvm.org/viewvc/llvm-project?rev=238713&view=rev
Log:
Apply name change to tools/* files.

These changes are all in comments.  Change libiomp references to
libomp.

Modified:
    openmp/trunk/runtime/tools/check-depends.pl
    openmp/trunk/runtime/tools/check-execstack.pl
    openmp/trunk/runtime/tools/check-instruction-set.pl
    openmp/trunk/runtime/tools/required-objects.pl

Modified: openmp/trunk/runtime/tools/check-depends.pl
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/runtime/tools/check-depends.pl?rev=238713&r1=238712&r2=238713&view=diff
==============================================================================
--- openmp/trunk/runtime/tools/check-execstack.pl (original)
+++ openmp/trunk/runtime/tools/check-execstack.pl Sun May 31 21:41:44 2015
@@ -136,9 +136,9 @@ A name of executable or shared object to
 
 =head1 EXAMPLES
 
-Check libiomp5.so library:
+Check libomp.so library:
 
-    $ check-execstack.pl libiomp5.so
+    $ check-execstack.pl libomp.so
 
 =cut
 

Modified: openmp/trunk/runtime/tools/check-instruction-set.pl
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/runtime/tools/check-instruction-set.pl?rev=238713&r1=238712&r2=238713&view=diff
==============================================================================
--- openmp/trunk/runtime/tools/check-instruction-set.pl (original)
+++ openmp/trunk/runtime/tools/check-instruction-set.pl Sun May 31 21:41:44 2015
@@ -132,9 +132,9 @@ sub check_file($;$$) {
             # Empty line.
             # Ignore.
         } elsif ( $line =~ m{^In archive (.*?):\s*$} ) {
-            # In archive libiomp5.a:
+            # In archive libomp.a:
         } elsif ( $line =~ m{^(?:.*?):\s*file format (.*?)\s*$} ) {
-            # libiomp5.so:     file format elf64-x86-64-freebsd
+            # libomp.so:     file format elf64-x86-64-freebsd
             # kmp_ftn_cdecl.o:     file format elf64-x86-64
             my $fmt = $1;
             if ( bad_fmt( $fmt ) ) {

Modified: openmp/trunk/runtime/tools/required-objects.pl
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/runtime/tools/required-objects.pl?rev=238713&r1=238712&r2=238713&view=diff
==============================================================================
--- openmp/trunk/runtime/tools/required-objects.pl (original)
+++ openmp/trunk/runtime/tools/required-objects.pl Sun May 31 21:41:44 2015
@@ -145,7 +145,7 @@ sub _load_symbols_nm($) {
             die "nm reported unknown object file:\n    $line\n";
         }; # if
         # AC: exclude some libc symbols from renaming, otherwise we have problems
-        #     in tests for gfortran + static libiomp on Lin_32.
+        #     in tests for gfortran + static libomp on Lin_32.
         #     These symbols came from libtbbmalloc.a
         if ( $target_os eq "lin" ) {
             if ( $symbol =~ m{__i686} ) {





More information about the Openmp-commits mailing list
--- openmp/trunk/runtime/tools/check-depends.pl (original)
+++ openmp/trunk/runtime/tools/check-depends.pl Sun May 31 21:41:44 2015
@@ -77,14 +77,14 @@ sub get_deps_ldd($) {
 # --------------------------------------------------------------------------------------------------
 # Another Linux* OS version of get_deps() parses output of readelf:
 #
-# $ readelf -d exports/lin_32e/lib/libiomp5.so
+# $ readelf -d exports/lin_32e/lib/libomp.so
 #
 # Dynamic segment at offset 0x87008 contains 24 entries:
 #   Tag        Type                         Name/Value
 #  0x0000000000000001 (NEEDED)             Shared library: [libc.so.6]
 #  0x0000000000000001 (NEEDED)             Shared library: [libdl.so.2]
 #  0x0000000000000001 (NEEDED)             Shared library: [libpthread.so.0]
-#  0x000000000000000e (SONAME)             Library soname: [libiomp5.so]
+#  0x000000000000000e (SONAME)             Library soname: [libomp.so]
 #  0x000000000000000d (FINI)               0x51caa
 #  0x0000000000000004 (HASH)               0x158
 #  0x0000000000000005 (STRTAB)             0x9350
@@ -149,8 +149,8 @@ sub get_deps_readelf($) {
 # OS X* version of get_deps() parses output of otool:
 #
 # $ otool -L libname.dylib
 # exports/mac_32/lib.thin/libiomp5.dylib:
 #        libiomp5.dylib (compatibility version 5.0.0, current version 5.0.0)
 #        /usr/lib/libSystem.B.dylib (compatibility version 1.0.0, current version 88.1.3)
 #
 sub get_deps_otool($) {
@@ -207,7 +207,7 @@ sub get_deps_otool($) {
 # > link -dump -dependents libname.dll
 # Microsoft (R) COFF/PE Dumper Version 8.00.40310.39
 # Copyright (C) Microsoft Corporation.  All rights reserved.
 # Dump of file S:\Projects.OMP\users\omalyshe\omp\libomp\exports\win_64\lib\libiomp5md.dll
 # File Type: DLL
 #   Image has the following dependencies:
 #     KERNEL32.dll
@@ -470,7 +470,7 @@ A name of library to find or check depen
 
 Just print library dependencies (Windows* OS):
 
-    > check-depends.pl exports/win_32/lib/libiomp5.dll
+    > check-depends.pl exports/win_32/lib/libompmd.dll
     check-depends.pl: (i) Dependencies:
     check-depends.pl: (i)     kernel32.dll
 
@@ -483,7 +483,7 @@ Print library dependencies, use bare out
 
 Check the library does not have any dependencies (OS X*):
 
-    $ check-depends.pl --expected=none exports/mac_32/lib/libiomp5.dylib
+    $ check-depends.pl --expected=none exports/mac_32/lib/libomp.dylib
     check-depends.pl: (i) Dependencies:
     check-depends.pl: (i)     /usr/lib/libSystem.B.dylib
     check-depends.pl: (x) Unexpected dependencies:
@@ -149,8 +149,8 @@ sub get_deps_readelf($) {
 #
 # $ otool -L libname.dylib
-# exports/mac_32/lib.thin/libiomp5.dylib:
-#        libiomp5.dylib (compatibility version 5.0.0, current version 5.0.0)
+# exports/mac_32/lib.thin/libomp.dylib:
+#        libomp.dylib (compatibility version 5.0.0, current version 5.0.0)
 #        /usr/lib/libSystem.B.dylib (compatibility version 1.0.0, current version 88.1.3)
 #
@@ -207,7 +207,7 @@ sub get_deps_otool($) {
 # Microsoft (R) COFF/PE Dumper Version 8.00.40310.39
 # Copyright (C) Microsoft Corporation.  All rights reserved.
-# Dump of file S:\Projects.OMP\users\omalyshe\omp\libomp\exports\win_64\lib\libiomp5md.dll
+# Dump of file S:\Projects.OMP\users\omalyshe\omp\libomp\exports\win_64\lib\libompmd.dll
 # File Type: DLL
 #   Image has the following dependencies:

Modified: openmp/trunk/runtime/tools/check-execstack.pl
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/runtime/tools/check-execstack.pl?rev=238713&r1=238712&r2=238713&view=diff
==============================================================================